/* SPDX-License-Identifier: GPL-2.0 */
/*
 * FPU data structures
 *
 * Copyright IBM Corp. 2015
 * Author(s): Hendrik Brueckner <brueckner@linux.vnet.ibm.com>
 */

#ifndef _ASM_S390_FPU_TYPES_H
#define _ASM_S390_FPU_TYPES_H

#include <asm/sigcontext.h>

struct fpu {
	__u32 fpc;		/* Floating-point control */
	void *regs;		/* Pointer to the current save area */
	union {
		/* Floating-point register save area */
		freg_t fprs[__NUM_FPRS];
		/* Vector register save area */
		__vector128 vxrs[__NUM_VXRS];
	};
};

/* In-kernel FPU state structure */
struct kernel_fpu {
	int	    mask;
	u32	    fpc;
	union {
		freg_t fprs[__NUM_FPRS];
		__vector128 vxrs[__NUM_VXRS];
	};
};

#define DECLARE_KERNEL_FPU_ONSTACK(name)	\
	struct kernel_fpu name __uninitialized

#endif /* _ASM_S390_FPU_TYPES_H */
